# Binning

Bin data along an axis.

This operation creates equally spaced bins (in linear or log space) along an axis and adds a condition assigning each event to a bin. The value of the event’s condition is the left end of the bin’s interval in which the event is located.

Name

  The name of the new condition created by this operation.

Channel

  The channel to apply the binning to.

Scale

  The scale to apply to the channel before binning.

Bin Width

  How wide should each bin be? Can only set if Scale is linear or log (in which case, Bin Width is in log10-units.)